@@ -22,8 +22,8 @@ const project = new cdk.JsiiProject({
     mavenEndpoint: 'https://s01.oss.sonatype.org',
   },
   publishToNuget: {
-    dotNetNamespace: 'Lazinessdevs.Lazy',
-    packageId: 'Lazyconstructs',
+    dotNetNamespace: 'LazinessDevs.Lazy',
+    packageId: 'LazyConstructs',
   },
 
 
